@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Iterate a counter up and back
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0201';
 
 use Carp qw( croak );
 use Moo;
@@ -36,7 +36,7 @@ has bottom => (
 
 has top => (
     is      => 'rw',
-    isa     => sub { croak "$_[0] is not an integer" unless $_[0] =~ /^\d+$/ },
+    isa     => sub { croak "$_[0] is not a number" unless looks_like_number( $_[0] ) },
     default => sub { 100 },
 );
 
@@ -98,7 +98,7 @@ Iterator::Breathe - Iterate a counter up and back
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSIS
 
@@ -134,7 +134,7 @@ wave-like fashion.
 
 Return or set the current value of C<direction>.
 
-Default: C<1>
+Default: C<1> (1=up, 0=down)
 
 =head2 i
 
@@ -184,7 +184,7 @@ Default: C<0>
 
 =head2 new
 
-  $it = Iterator::Breathe->new(verbose => 1);
+  $it = Iterator::Breathe->new( %arguments );
 
 Create a new C<Iterator::Breathe> object.
 
@@ -196,6 +196,8 @@ Create a new C<Iterator::Breathe> object.
 
 L<Moo>
 
+L<Scalar::Util>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
